@@ -2,6 +2,13 @@ import os
 import sys
 import yaml
 
+notifier = None
+try:
+    from gntp import notifier
+    import socket
+except ImportError:
+    pass
+
 from fnmatch import fnmatch
 from strange_case.registry import Registry
 from strange_case.processors import build_node
@@ -33,8 +40,6 @@ def strange_case(config):
 
     # this is the one folder that *doesn't* get processed by processors.build_page_tree,
     # so it needs special handling here.
-    # config_path = os.path.join(deploy_path, config['config_file'])
-    # config.update(check_for_config(config_path))
     config.setdefault('type', 'root')
     Node.files_written = []
     root_node = build_node(config, site_path, deploy_path, '')[0]
@@ -69,6 +74,26 @@ def strange_case(config):
             sys.stderr.write("\033[31mrmdir\033[0m \033[1m" + p_rel + "\033[0m\n")
             os.removedirs(p)
 
+    if notifier:
+        try:
+            growl = notifier.GrowlNotifier(
+                applicationName="StrangeCase",
+                notifications=["New Messages"],
+                defaultNotifications=["New Messages"],
+            )
+            growl.register()
+
+            # Send one message
+            growl.notify(
+                noteType="New Messages",
+                title="StrangeCase site generated",
+                description="site is available at:\n"
+                    "{config[deploy_path]}"\
+                    .format(config=config),
+            )
+        except socket.error:
+            pass
+
 
 def fancy_import(import_name):
     """
